# HeFESTo_Parameters_010121
Parameter set 010121 for use with the code:
HeFESTo by L. Stixrude and C. Lithgow-Bertelloni, 2005-
https://github.com/stixrude/HeFESToRepository

If you use this parameter set, please cite:

(1) Stixrude, L. and C. Lithgow-Bertelloni, Thermal expansivity, heat capacity and bulk modulus of the mantle, Geophysical Journal International, 228, 1119-1149, 2022.

If you also use HeFESTo, please cite the following for the source of the HeFESTo code:

(2) Stixrude, L. and C. Lithgow-Bertelloni, Thermodynamics of mantle minerals - I. Physical properties, Geophysical Journal International, 162, 610-632, 2005.

(3) Stixrude, L. and C. Lithgow-Bertelloni, Thermodynamics of mantle minerals - II. Phase equilibria, Geophysical Journal International, 184, 1180-1213, 2011.

Additional Notes.  Parameter files of the following species have not yet been discussed in the published literature and are not recommended as they are still being optimized: crst, enm, fapv, fea, fee, feg, flpv, hem, hepv, hlpv, hmag, hppv, lppv, mag, mgl, sil, wuls

***** WARNING *****  

We grant the right to download and use this data, but do not grant the right to redistribute modified versions of the data in any form. If you have questions about the data, suggestions for improvements, or would like to ask for additional permissions or data files, please contact the authors:

Lars Stixrude: lstixrude@epss.ucla.edu
Carolina Lithgow-Bertelloni: clb@epss.ucla.edu
